// -*- coding: euc-jp-unix -*-
// J.DepP -- Japanese Dependency Parsers
//  $Id: jdepp_conf.h 762 2012-01-04 15:37:59Z ynaga $
// Copyright (c) 2008-2011 Naoki Yoshinaga <ynaga@tkl.iis.u-tokyo.ac.jp>
#ifndef JDEPP_CONFIG_H
#define JDEPP_CONFIG_H
// configure options for J.DepP

// specify a frontend morphological analyzer (field format)
#define USE_MECAB
// #define USE_JUMAN

// integrate MeCab into J.DepP to read raw sentences (need -lmecab)
// unset this option to build J.DepP that read MeCab output (word/POS sequences)
#define USE_AS_STANDALONE

// specify POS set (field) used in the frontend morphological analysis
#if   defined (USE_JUMAN) // Juman accept only JUMAN POS
#define USE_JUMAN_POS
#elif defined (USE_MECAB)
#define USE_JUMAN_POS
// #define USE_IPA_POS
#endif

// use features employed in Yoshinaga and Kitsuregawa (EMNLP 2009)
// unset to achieve +1% (91%->92%) partial accuracy in dependency parsing
// (but the parsing speed will be 1.5 to 2 times slower)
// #define USE_EMNLP_FEAT
#ifdef USE_EMNLP_FEAT
#ifndef USE_JUMAN_POS
#define USE_JUMAN_POS
#endif
#undef USE_IPA_POS
#endif

// specify IOBUF_SIZE to a value that is larger than the input training data
// (for one senence)
#define IOBUF_SIZE (1 << 20)

// specify default mecab dictionary; overridden by the option [-d]
// #define JDEPP_MECAB_DIC "/usr/local/lib/mecab/dic/jumandic"

// do not edit from here
// posset specific variables
#define COMMA         ""
#define PERIOD        ""
#define POST_PARTICLE ""

#if defined (USE_JUMAN_POS)
#define BRACKET_START "̻"
#define BRACKET_END   "̽"
#ifdef USE_EMNLP_FEAT
#define SUFFIX        ""
#endif
#define SPECIAL       "ü"
#elif defined (USE_IPA_POS)
#define BRACKET_START "̳"
#define BRACKET_END   ""
#define SPECIAL       ""
#endif

#if   defined (USE_MECAB)
#define SURFACE_END  '\t'
#define FEATURE_SEP  ','
#elif defined (USE_JUMAN)
#define SURFACE_END  ' '
#define FEATURE_SEP  ' '
#endif

#endif /* PECCO_CONFIG_H */
