#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Usage: to_tree.py < in.JDP
#   translate parser output into human-readable dependency tree structure
import re, sys

# customizable parameters
indent = 3          # for one dependency arc
offset = 2          # offset from the left
color  = "\033[31m" # color (red) for incorrect dependency arc

class Binfo:
    """ bunsetsu infomation """
    def __init__ (self, *args):
        self.id, self.head, self.ok, self.gold = args
        self.morph, self.depth, self.first_child = "", 0, -1
    def len    (self)        : return len (unicode (self.morph, 'utf-8'))
    def offset (self, width) : return width - self.len () - self.depth

binfo  = []
for line in sys.stdin:
    if line[0] == '#':
        sys.stdout.write (line)
        binfo = []
    elif line[0] == 'E': # EOS
        for c in reversed (binfo[:-1]):
            c.depth = binfo[c.head].depth + indent
            binfo[c.head].first_child = c.id
        width = offset + max (b.len () + b.depth for b in binfo) # tree width
        for b in binfo:
            if b.head == -1:
                sys.stdout.write ("% 3d:%s%s" % (b.id, "　" * b.offset (width),
                                                 b.morph))
            else:
                output = "" if b.ok else color
                output += "% 3d:%s%s" % (b.id, "　" * b.offset (width), b.morph)
                h = binfo[b.head]
                output += "━" * (b.depth - h.depth - 1) # ─
                output += "┓" if b.id == h.first_child else "┫" # ┐ ┤
                output += "" if b.ok else "%-4s\033[0m" % b.gold
                while h.head != -1: # draw arcs spanning from x < b to y > h
                    c, h = h, binfo[h.head]
                    output += "　" * (c.depth - h.depth - (1 if b.ok else 3))
                    output += "┃" if h.first_child < b.id else "　" # │
                    b.ok = True
                sys.stdout.write (output + "\n")
        sys.stdout.write (line)
    elif line[0] == '*':
        h, g = (line[:-1] + "#-1D").split (' ')[2].split('#')[:2]
        binfo.append (Binfo (len (binfo), int (h[:-1]),
                             g[:-1] == "-1" or h[:-1] == g[:-1], g))
    else:
        surface = re.split('[\t ]', line[:-1])[0]
        binfo[-1].morph += surface
